#
# spec file for package php-smbclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name smbclient

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif

Name:           %{php_name}-%{pkg_name}
Version:        1.1.2
Release:        1.3
Summary:        A PHP wrapper for libsmbclient
License:        PHP-3.01
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/package/smbclient
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
Source1:        php-%{pkg_name}-rpmlintrc
BuildRequires:  %{php_name}-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(smbclient)
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
Provides:       php-smbclient = %{version}
Obsoletes:      php-smbclient < %{version}

%description
smbclient is a PHP extension that uses Samba's libsmbclient library to provide
Samba related functions and 'smb' streams to PHP programs.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
export CFLAGS="%{optflags} -fvisibility=hidden"
%{__phpize}
%configure
%make_build

%check
%make_build test PHP_EXECUTABLE=%{_bindir}/php NO_INTERACTION=1

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat > %{buildroot}%{php_cfgdir}/%{pkg_name}.ini << EOF
; comment out next line to disable %{pkg_name} extension in php
extension = %{pkg_name}.so
EOF

%files
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Tue Dec  3 2024 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.1.2
  * Build fixes.
* Tue Apr 18 2023 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.1.1
  * Workaround for regression in libsmbclient 4.16.9 and 4.17.5.
* Mon Apr  3 2023 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.1.0
  * PHP 8 readiness
- Update to version 1.0.7
  * xattr fix
* Sat Dec 10 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove php7 build for Tumbleweed (PHP 7.4 has reached EOL)
* Sun Feb 28 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.0.6
  * ftruncate implemented on smb_streams
* Fri Feb 19 2021 Arjen de Korte <suse+build@de-korte.org>
- Mention rpmlintrc file in spec
  + php-smbclient-rpmlintrc
* Wed Feb 17 2021 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to also build for php8
* Thu Feb 11 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.0.5
  * Fixes possible segfault in php_smb_ops_close.
* Fri Jan 22 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.0.4
  * Check if smbc_setOptionProtocols is available, as at least one
    distro might have a libsmbclient that is too old.
* Thu Jan 21 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to version 1.0.3
  * Add client min/max protocol to streams, and make either min/max
    optional.
- Update to version 1.0.2
  * Introduces smbclient_client_protocols() to set min and max
    protocol for negotiation.
* Sun Jan 17 2021 Arjen de Korte <suse+build@de-korte.org>
- Upgrade to version 1.0.1
  * Code fixes for PHP 7.4/8, and memory free, ReadTest added,
    Travis build updated, and smbclient_state_init documentation fixed
- Remove patch (upstreamed)
  - 0001-fix-incorrect-deallocation-of-zend_string.patch
- Use php_cfgdir and php_extdir macros to determine location of files
* Fri Jan 11 2019 Cristian Rodríguez <crodriguez@owncloud.com>
- Upgrade to version 1.0.0 (boo#1123503)
  * stream optimization: reuse previous connections (Remi)
- 0001-fix-incorrect-deallocation-of-zend_string.patch: zend_strings
  are to be zend_string_release()'ed not efree()'ed.
* Thu Dec 20 2018 jweberhofer@weberhofer.at
- Added php7-smbclient-fix_for_PHP_7.3.patch to allow building with PHP 7.3
  as discussed in gh#eduardok/libsmbclient-php#60
* Mon Jul 23 2018 idonmez@suse.com
- Cleanup with spec-cleaner
* Tue Mar 27 2018 crrodriguez@opensuse.org
- Build module with -fvisibility=hidden
* Mon Nov 20 2017 crrodriguez@opensuse.org
- Initial version for php 7
